@@ -99,15 +99,23 @@ struct _GdaDataModelClass {
 	void                 (* i_set_notify)       (GdaDataModel *model, gboolean do_notify_changes);
 	gboolean             (* i_get_notify)       (GdaDataModel *model);
 	void                 (* i_send_hint)        (GdaDataModel *model, GdaDataModelHint hint, const GValue *hint_value);
+	gpointer                reserved1;
+	gpointer                reserved2;
+	gpointer                reserved3;
+	gpointer                reserved4;
 
 	/* signals */
 	void                 (* row_inserted)       (GdaDataModel *model, gint row);
 	void                 (* row_updated)        (GdaDataModel *model, gint row);
 	void                 (* row_removed)        (GdaDataModel *model, gint row);
 	void                 (* reset)              (GdaDataModel *model);
+	gpointer                sig_reserved1;
+	gpointer                sig_reserved2;
+	gpointer                sig_reserved3;
+	gpointer                sig_reserved4;
 };
 
-GType               gda_data_model_get_type               (void);
+GType               gda_data_model_get_type               (void) G_GNUC_CONST;
 
 gboolean            gda_data_model_is_updatable           (GdaDataModel *model);
 GdaDataModelAccessFlags gda_data_model_get_access_flags       (GdaDataModel *model);
@@ -117,6 +125,8 @@ gint                gda_data_model_get_n_columns          (GdaDataModel *model);
 
 GdaColumn          *gda_data_model_describe_column        (GdaDataModel *model, gint col);
 gint                gda_data_model_get_column_index_by_name(GdaDataModel *model, const gchar *name);
+const gchar        *gda_data_model_get_column_name       (GdaDataModel *model, gint col);
+void                gda_data_model_set_column_name       (GdaDataModel *model, gint col, const gchar *name);
 const gchar        *gda_data_model_get_column_title       (GdaDataModel *model, gint col);
 void                gda_data_model_set_column_title       (GdaDataModel *model, gint col, const gchar *title);
 
