@@ -118,7 +118,7 @@ gda_dict_constraint_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaDictConstraintClass),
 			(GBaseInitFunc) NULL,
