@@ -1,21 +1,21 @@
 /* gda-dict-field.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "gda-dict-field.h"
@@ -58,11 +58,13 @@ static gboolean    gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePt
 /* GdaEntityField interface */
 static void           gda_dict_field_field_init       (GdaEntityFieldIface *iface);
 static GdaEntity      *gda_dict_field_get_entity      (GdaEntityField *iface);
-static GdaDictType    *gda_dict_field_get_data_type   (GdaEntityField *iface);
+static GdaDictType    *gda_dict_field_get_dict_type   (GdaEntityField *iface);
+static void           gda_dict_field_set_dict_type   (GdaEntityField *iface, GdaDictType *type);
 
 /* Renderer interface */
 static void            gda_dict_field_renderer_init   (GdaRendererIface *iface);
-static gchar          *gda_dict_field_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar          *gda_dict_field_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+						       GSList **out_params_used, GdaRendererOptions options, GError **error);
 static gchar          *gda_dict_field_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 #ifdef GDA_DEBUG
@@ -80,19 +82,20 @@ enum
 {
 	PROP_0,
 	PROP_DB_TABLE,
-	PROP_PLUGIN
+	PROP_PLUGIN,
+	PROP_DICT_TYPE
 };
 
 
 /* private structure */
 struct _GdaDictFieldPrivate
 {
-	GdaDictType     *data_type;
+	GdaDictType     *dict_type;
 	GdaDictTable    *table;
 	gint             length;     /* -1 if not applicable */
 	gint             scale;      /* 0 if not applicable */
 	GValue          *default_val;/* NULL if no default value */
-	guint            extra_attrs;/* OR'ed value of GdaDictFieldAttribute */
+	GdaDictFieldAttribute extra_attrs;/* OR'ed value of GdaDictFieldAttribute */
 	gchar           *plugin;
 };
 
@@ -111,7 +114,7 @@ gda_dict_field_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaDictFieldClass),
 			(GBaseInitFunc) NULL,
@@ -163,7 +166,8 @@ static void
 gda_dict_field_field_init (GdaEntityFieldIface *iface)
 {
 	iface->get_entity = gda_dict_field_get_entity;
-	iface->get_data_type = gda_dict_field_get_data_type;
+	iface->get_dict_type = gda_dict_field_get_dict_type;
+	iface->set_dict_type = gda_dict_field_set_dict_type;
 }
 
 static void
@@ -188,7 +192,8 @@ gda_dict_field_class_init (GdaDictFieldClass * class)
 	object_class->set_property = gda_dict_field_set_property;
 	object_class->get_property = gda_dict_field_get_property;
 	g_object_class_install_property (object_class, PROP_DB_TABLE,
-					 g_param_spec_pointer ("db_table", NULL, NULL, 
+					 g_param_spec_object ("db_table", NULL, NULL, 
+                                                               GDA_TYPE_DICT_TABLE,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_PLUGIN,
                                          g_param_spec_string ("entry_plugin", NULL, NULL, NULL,
@@ -205,7 +210,7 @@ gda_dict_field_init (GdaDictField * gda_dict_field)
 {
 	gda_dict_field->priv = g_new0 (GdaDictFieldPrivate, 1);
 	gda_dict_field->priv->table = NULL;
-	gda_dict_field->priv->data_type = NULL;
+	gda_dict_field->priv->dict_type = NULL;
 	gda_dict_field->priv->length = -1;
 	gda_dict_field->priv->scale = 0;
 	gda_dict_field->priv->extra_attrs = 0;
@@ -236,7 +241,7 @@ gda_dict_field_new (GdaDict *dict, GdaDictType *type)
 	gda_dict_field = GDA_DICT_FIELD (obj);
 
 	if (type)
-		gda_dict_field_set_dict_type (gda_dict_field, type);
+		gda_dict_field_set_dict_type (GDA_ENTITY_FIELD(gda_dict_field), type);
 	
 	return obj;
 }
@@ -264,11 +269,11 @@ gda_dict_field_dispose (GObject *object)
 							      G_CALLBACK (destroyed_object_cb), gda_dict_field);
 			gda_dict_field->priv->table = NULL;
 		}
-		if (gda_dict_field->priv->data_type) {
-			g_signal_handlers_disconnect_by_func (G_OBJECT (gda_dict_field->priv->data_type),
+		if (gda_dict_field->priv->dict_type) {
+			g_signal_handlers_disconnect_by_func (G_OBJECT (gda_dict_field->priv->dict_type),
 							      G_CALLBACK (destroyed_object_cb), gda_dict_field);
-			g_object_unref (gda_dict_field->priv->data_type);
-			gda_dict_field->priv->data_type = NULL;
+			g_object_unref (gda_dict_field->priv->dict_type);
+			gda_dict_field->priv->dict_type = NULL;
 		}
 	}
 
@@ -303,26 +308,26 @@ gda_dict_field_set_property (GObject *object,
 			     const GValue *value,
 			     GParamSpec *pspec)
 {
-	gpointer ptr;
 	GdaDictField *gda_dict_field;
 
 	gda_dict_field = GDA_DICT_FIELD (object);
 	if (gda_dict_field->priv) {
 		switch (param_id) {
-		case PROP_DB_TABLE:
+		case PROP_DB_TABLE: {
 			if (gda_dict_field->priv->table) {
 				g_signal_handlers_disconnect_by_func (G_OBJECT (gda_dict_field->priv->table),
 								      G_CALLBACK (destroyed_object_cb), gda_dict_field);
-				gda_dict_field->priv->table = NULL;
+				gda_dict_field->priv->table = NULL; /* TODO: unref it? */
 			}
 
-			ptr = g_value_get_pointer (value);
+			GdaDictTable* ptr = GDA_DICT_TABLE (g_value_get_object (value));
 			if (ptr && GDA_IS_DICT_TABLE (ptr)) {
-				gda_dict_field->priv->table = GDA_DICT_TABLE (ptr);
+				gda_dict_field->priv->table = GDA_DICT_TABLE (ptr); /* TODO: ref it? */
 				gda_object_connect_destroy (ptr,
 							 G_CALLBACK (destroyed_object_cb), gda_dict_field);
 			}
 			break;
+                }
 		case PROP_PLUGIN:
 			g_free (gda_dict_field->priv->plugin);
 			if (g_value_get_string (value))
@@ -346,7 +351,7 @@ gda_dict_field_get_property (GObject *object,
 	if (gda_dict_field->priv) {
 		switch (param_id) {
 		case PROP_DB_TABLE:
-			g_value_set_pointer (value, gda_dict_field->priv->table);
+			g_value_set_object (value, G_OBJECT (gda_dict_field->priv->table));
 			break;
 		case PROP_PLUGIN:
 			g_value_set_string (value, gda_dict_field->priv->plugin);
@@ -382,7 +387,7 @@ gda_dict_field_set_length (GdaDictField *field, gint length)
 
 	/* signal the modification */
 	if (changed)
-		gda_object_changed (GDA_OBJECT (field));
+		gda_object_signal_emit_changed (GDA_OBJECT (field));
 }
 
 /**
@@ -427,7 +432,7 @@ gda_dict_field_set_scale (GdaDictField *field, gint scale)
 
 	/* signal the modification */
 	if (changed)
-		gda_object_changed (GDA_OBJECT (field));
+		gda_object_signal_emit_changed (GDA_OBJECT (field));
 }
 
 /**
@@ -451,7 +456,7 @@ gda_dict_field_get_scale (GdaDictField *field)
  * gda_dict_field_get_constraints
  * @field: a #GdaDictField  object
  *
- * Get all the constraints which impact the given field. Constraints are of several type:
+ * Get all the constraints which affect the given field. Constraints are of several type:
  * NOT NULL, primary key, foreign key, check constrains
  *
  * Returns: a new list of #GdaDictConstraint objects
@@ -478,32 +483,6 @@ gda_dict_field_get_constraints (GdaDictField *field)
 	return retval;
 }
 
-/**
-* gda_dict_field_set_dict_type
-* @field: a #GdaDictField  object
-* @type: a #GdaDictType object
-*
-* Sets the data type of the field
-*/
-void
-gda_dict_field_set_dict_type (GdaDictField *field, GdaDictType *type)
-{
-	g_return_if_fail (field && GDA_IS_DICT_FIELD (field));
-	g_return_if_fail (field->priv);
-	g_return_if_fail (type && GDA_IS_DICT_TYPE (type));
-
-	if (field->priv->data_type != type) {
-		if (field->priv->data_type)
-			g_signal_handlers_disconnect_by_func (G_OBJECT (field->priv->data_type),
-							      G_CALLBACK (destroyed_object_cb), field);
-		field->priv->data_type = type;
-		g_object_ref (type);
-		gda_object_connect_destroy (type, G_CALLBACK (destroyed_object_cb), field);
-		
-		/* signal the modification */
-		gda_object_changed (GDA_OBJECT (field));
-	}
-}
 
 
 /**
@@ -531,7 +510,7 @@ gda_dict_field_set_default_value (GdaDictField *field, const GValue *value)
 			field->priv->default_val = gda_value_copy ((GValue *) value);
 		
 		/* signal the modification */
-		gda_object_changed (GDA_OBJECT (field));
+		gda_object_signal_emit_changed (GDA_OBJECT (field));
 	}
 }
 
@@ -729,7 +708,7 @@ gda_dict_field_is_fkey_alone (GdaDictField *field)
  * values in #GdaDictFieldAttribute.
  */
 void
-gda_dict_field_set_attributes (GdaDictField *field, guint attributes)
+gda_dict_field_set_attributes (GdaDictField *field, GdaDictFieldAttribute attributes)
 {
 	g_return_if_fail (field && GDA_IS_DICT_FIELD (field));
 	g_return_if_fail (field->priv);
@@ -746,7 +725,7 @@ gda_dict_field_set_attributes (GdaDictField *field, guint attributes)
  *
  * Returns: the new attributes value
  */
-guint
+GdaDictFieldAttribute
 gda_dict_field_get_attributes (GdaDictField *field)
 {
 	g_return_val_if_fail (field && GDA_IS_DICT_FIELD (field), 0);
@@ -794,12 +773,36 @@ gda_dict_field_get_entity (GdaEntityField *iface)
 }
 
 static GdaDictType *
-gda_dict_field_get_data_type (GdaEntityField *iface)
+gda_dict_field_get_dict_type (GdaEntityField *iface)
 {
 	g_return_val_if_fail (iface && GDA_IS_DICT_FIELD (iface), NULL);
 	g_return_val_if_fail (GDA_DICT_FIELD (iface)->priv, NULL);
 
-	return GDA_DICT_FIELD (iface)->priv->data_type;
+	return GDA_DICT_FIELD (iface)->priv->dict_type;
+}
+
+static void
+gda_dict_field_set_dict_type (GdaEntityField *iface, GdaDictType *type)
+{
+	GdaDictField *field;
+	
+	field = GDA_DICT_FIELD (iface);
+	
+	g_return_if_fail (field && GDA_IS_DICT_FIELD (field));
+	g_return_if_fail (field->priv);
+	g_return_if_fail (type && GDA_IS_DICT_TYPE (type));
+
+	if (field->priv->dict_type != type) {
+		if (field->priv->dict_type)
+			g_signal_handlers_disconnect_by_func (G_OBJECT (field->priv->dict_type),
+							      G_CALLBACK (destroyed_object_cb), field);
+		field->priv->dict_type = type;
+		g_object_ref (type);
+		gda_object_connect_destroy (type, G_CALLBACK (destroyed_object_cb), field);
+		
+		/* signal the modification */
+		gda_object_signal_emit_changed (GDA_OBJECT (field));
+	}
 }
 
 /* 
@@ -814,7 +817,7 @@ gda_dict_field_get_xml_id (GdaXmlStorage *iface)
 	g_return_val_if_fail (GDA_DICT_FIELD (iface)->priv, NULL);
 
 	t_xml_id = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (GDA_DICT_FIELD (iface)->priv->table));
-	tmp = utility_build_encoded_id ("FI", gda_object_get_name (GDA_OBJECT (iface)));
+	tmp = gda_utility_build_encoded_id ("FI", gda_object_get_name (GDA_OBJECT (iface)));
 	xml_id = g_strconcat (t_xml_id, ":", tmp, NULL);
 	g_free (t_xml_id);
 	g_free (tmp);
@@ -834,23 +837,23 @@ gda_dict_field_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	field = GDA_DICT_FIELD (iface);
 
-	node = xmlNewNode (NULL, "gda_dict_field");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_dict_field");
 	
 	str = gda_dict_field_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (field)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (field)));
 	if (gda_object_get_owner (GDA_OBJECT (field)))
-		xmlSetProp (node, "owner", gda_object_get_owner (GDA_OBJECT (field)));
-	xmlSetProp (node, "descr", gda_object_get_description (GDA_OBJECT (field)));
-	str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (field->priv->data_type));
-	xmlSetProp (node, "type", str);
+		xmlSetProp(node, (xmlChar*)"owner", (xmlChar*)gda_object_get_owner (GDA_OBJECT (field)));
+	xmlSetProp(node, (xmlChar*)"descr", (xmlChar*)gda_object_get_description (GDA_OBJECT (field)));
+	str = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (field->priv->dict_type));
+	xmlSetProp(node, (xmlChar*)"type", (xmlChar*)str);
 	g_free (str);
 	str = g_strdup_printf ("%d", field->priv->length);
-	xmlSetProp (node, "length", str);
+	xmlSetProp(node, (xmlChar*)"length", (xmlChar*)str);
 	g_free (str);
 	str = g_strdup_printf ("%d", field->priv->scale);
-	xmlSetProp (node, "scale", str);
+	xmlSetProp(node, (xmlChar*)"scale", (xmlChar*)str);
 	g_free (str);
 
 	if (field->priv->default_val) {
@@ -858,22 +861,22 @@ gda_dict_field_save_to_xml (GdaXmlStorage *iface, GError **error)
 		GType vtype;
 		
 		vtype = G_VALUE_TYPE (field->priv->default_val);
-		xmlSetProp (node, "default_gda_type", gda_type_to_string (vtype));
+		xmlSetProp(node, (xmlChar*)"default_g_type", (xmlChar*)gda_g_type_to_string (vtype));
 
 		dh = gda_dict_get_default_handler (gda_object_get_dict (GDA_OBJECT (field)), vtype);
 		str = gda_data_handler_get_str_from_value (dh, field->priv->default_val);
-		xmlSetProp (node, "default", str);
+		xmlSetProp(node, (xmlChar*)"default", (xmlChar*)str);
 		g_free (str);
 	}
 
-	str = utility_table_field_attrs_stringify (field->priv->extra_attrs);
+	str = gda_utility_table_field_attrs_stringify (field->priv->extra_attrs);
 	if (str) {
-		xmlSetProp (node, "extra_attr", str);
+		xmlSetProp(node, (xmlChar*)"extra_attr", (xmlChar*)str);
 		g_free (str);
 	}
 
 	if (field->priv->plugin && *(field->priv->plugin)) 
-		xmlSetProp (node, "plugin", field->priv->plugin);
+		xmlSetProp(node, (xmlChar*)"plugin", (xmlChar*)field->priv->plugin);
 
 	return node;
 }
@@ -892,7 +895,7 @@ gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 
 	field = GDA_DICT_FIELD (iface);
 	dict = gda_object_get_dict (GDA_OBJECT (field));
-	if (strcmp (node->name, "gda_dict_field")) {
+	if (strcmp ((gchar*)node->name, "gda_dict_field")) {
 		g_set_error (error,
 			     GDA_DICT_FIELD_ERROR,
 			     GDA_DICT_FIELD_XML_LOAD_ERROR,
@@ -900,53 +903,53 @@ gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		name = TRUE;
 		gda_object_set_name (GDA_OBJECT (field), prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "descr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"descr");
 	if (prop) {
 		gda_object_set_description (GDA_OBJECT (field), prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "owner");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"owner");
 	if (prop) {
 		gda_object_set_owner (GDA_OBJECT (field), prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "type");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"type");
 	if (prop) {
 		if ((*prop == 'D') && prop+1 && (*(prop+1) == 'T')) {
 			GdaDictType *dt = gda_dict_get_dict_type_by_xml_id (dict, prop);
 			if (dt) 
-				gda_dict_field_set_dict_type (field, dt);
+				gda_dict_field_set_dict_type (GDA_ENTITY_FIELD(field), dt);
 			else {
 				/* create a new custom data type */
 				gchar *tmp, *tmp2;
 				xmlNodePtr tnode;
 				
 				dt = GDA_DICT_TYPE (gda_dict_type_new (dict));
-				tmp = utility_build_decoded_id (NULL, prop + 2);
+				tmp = gda_utility_build_decoded_id (NULL, prop + 2);
 				gda_dict_type_set_sqlname (dt, tmp);
 				g_free (tmp);
-				gda_dict_type_set_gda_type (dt, GDA_TYPE_BLOB);
+				gda_dict_type_set_g_type (dt, GDA_TYPE_BLOB);
 
 				tnode = node->parent;
-				g_assert (tnode && !strcmp (tnode->name, "gda_dict_table"));
-				tmp = xmlGetProp (tnode, "name");
+				g_assert (tnode && !strcmp ((gchar*)tnode->name, "gda_dict_table"));
+				tmp = (gchar*)xmlGetProp(tnode, (xmlChar*)"name");
 				g_assert (tmp);
-				tmp2 = g_strdup_printf (_("Custom data type, declared for the %s.%s field"),
+				tmp2 = (gchar*)g_strdup_printf (_("Custom data type, declared for the %s.%s field"),
 							tmp, gda_object_get_name (GDA_OBJECT (field)));
 				xmlFree (tmp);
 				gda_object_set_description (GDA_OBJECT (dt), tmp2);
 				g_free (tmp2);
-				gda_dict_declare_object (dict, dt);
-				gda_dict_field_set_dict_type (field, dt);
+				gda_dict_declare_object (dict, GDA_OBJECT(dt));
+				gda_dict_field_set_dict_type (GDA_ENTITY_FIELD (field), dt);
 				g_object_unref (dt);
 			}
 			type = TRUE;
@@ -954,29 +957,29 @@ gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "length");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"length");
 	if (prop) {
 		field->priv->length = atoi (prop);
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "scale");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"scale");
 	if (prop) {
 		field->priv->scale = atoi (prop);
 		xmlFree (prop);
 	}
 	
-	prop = xmlGetProp (node, "default");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"default");
 	if (prop) {
 		gchar *str2;
 
-		str2 = xmlGetProp (node, "default_gda_type");
+		str2 = (gchar*)xmlGetProp(node, (xmlChar*)"default_g_type");
 		if (str2) {
 			GType vtype;
 			GdaDataHandler *dh;
 			GValue *value;
 			
-			vtype = gda_type_from_string (str2);
+			vtype = gda_g_type_from_string (str2);
 			if (vtype == G_TYPE_INVALID) {
 				g_set_error (error,
 					     GDA_DICT_FIELD_ERROR,
@@ -1004,13 +1007,13 @@ gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "extra_attr");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"extra_attr");
 	if (prop) {
-		gda_dict_field_set_attributes (field, utility_table_field_attrs_parse (prop));
+		gda_dict_field_set_attributes (field, gda_utility_table_field_attrs_parse (prop));
 		xmlFree (prop);
 	}
 
-	prop = xmlGetProp (node, "plugin");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"plugin");
 	if (prop) {
 		g_object_set (G_OBJECT (field), "entry_plugin", prop, NULL);
 		xmlFree (prop);
@@ -1033,13 +1036,15 @@ gda_dict_field_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError **er
  */
 
 static gchar *
-gda_dict_field_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_dict_field_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+			      GSList **out_params_used, GdaRendererOptions options, GError **error)
 {
 	gchar *str = NULL;
 
 	g_return_val_if_fail (iface && GDA_IS_DICT_FIELD (iface), NULL);
 	g_return_val_if_fail (GDA_DICT_FIELD (iface)->priv, NULL);
 	
+        /* TODO: */
 	TO_IMPLEMENT;
 	return str;
 }
