@@ -2,20 +2,20 @@
  *
  * Copyright (C) 2003 - 2006 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "gda-dict-table.h"
@@ -126,7 +126,7 @@ gda_dict_table_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaDictTableClass),
 			(GBaseInitFunc) NULL,
@@ -652,7 +652,7 @@ gda_dict_table_update_dbms_data (GdaDictTable *table, GError **error)
 			str = gda_value_stringify ((GValue *) value);
 			type = gda_dict_get_dict_type_by_name (dict, str);
 			if (type)
-				gda_dict_field_set_dict_type (field, type);
+				gda_entity_field_set_dict_type (GDA_ENTITY_FIELD (field), type);
 			else {
 				/* declare a custom data type */
 				gchar *descr;
@@ -665,7 +665,7 @@ gda_dict_table_update_dbms_data (GdaDictTable *table, GError **error)
 				gda_object_set_description (GDA_OBJECT (type), descr);
 				g_free (descr);
 				gda_dict_declare_object (dict, (GdaObject *) type);
-				gda_dict_field_set_dict_type (field, type);
+				gda_entity_field_set_dict_type (GDA_ENTITY_FIELD (field), type);
 				g_object_unref (type);
 			}
 			g_free (str);
