@@ -251,7 +251,7 @@ gda_server_operation_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GdaServerOperationClass),
 			(GBaseInitFunc) NULL,
@@ -583,13 +583,16 @@ gda_server_operation_set_property (GObject *object,
 				xmlDoValidityCheckingDefaultValue = 1;
 				
 				/* replace the DTD with ours */
-				old_dtd = doc->intSubset;
-				doc->intSubset = gda_server_op_dtd;
-
-				if (! xmlValidateDocument (validc, doc)) {
+				if (gda_server_op_dtd) {
+					old_dtd = doc->intSubset;
+					doc->intSubset = gda_server_op_dtd;
+				}
+#ifndef G_OS_WIN32
+				if (doc->intSubset && !xmlValidateDocument (validc, doc)) {
 					gchar *str;
 					
-					doc->intSubset = old_dtd;
+					if (gda_server_op_dtd)
+						doc->intSubset = old_dtd;
 					xmlFreeDoc (doc);
 					g_free (validc);
 					str = g_object_get_data (G_OBJECT (op), "xmlerror");
@@ -606,10 +609,12 @@ gda_server_operation_set_property (GObject *object,
 					xmlDoValidityCheckingDefaultValue = xmlcheck;
 					return;
 				}
+#endif
 				
 				xmlDoValidityCheckingDefaultValue = xmlcheck;
 				g_free (validc);
-				doc->intSubset = old_dtd;
+				if (gda_server_op_dtd)
+					doc->intSubset = old_dtd;
 				op->priv->xml_spec_doc = doc;
 			}
 			else {
