@@ -63,43 +63,45 @@
      L_LBRACKET = 279,
      L_RBRACKET = 280,
      L_IDENT = 281,
-     L_EQ = 282,
-     L_IS = 283,
-     L_LIKE = 284,
-     L_GT = 285,
-     L_LT = 286,
-     L_GEQ = 287,
-     L_LEQ = 288,
-     L_DIFF = 289,
-     L_REGEXP = 290,
-     L_REGEXP_CI = 291,
-     L_NOTREGEXP = 292,
-     L_NOTREGEXP_CI = 293,
-     L_SIMILAR = 294,
-     L_NOT = 295,
-     L_AND = 296,
-     L_OR = 297,
-     L_MINUS = 298,
-     L_PLUS = 299,
-     L_TIMES = 300,
-     L_DIV = 301,
-     L_STRING = 302,
-     L_TEXTUAL = 303,
-     L_DELETE = 304,
-     L_JOIN = 305,
-     L_INNER = 306,
-     L_LEFT = 307,
-     L_RIGHT = 308,
-     L_FULL = 309,
-     L_OUTER = 310,
-     L_LSBRACKET = 311,
-     L_RSBRACKET = 312,
-     L_PNAME = 313,
-     L_PTYPE = 314,
-     L_PISPARAM = 315,
-     L_PDESCR = 316,
-     L_PNULLOK = 317,
-     L_UNSPECVAL = 318
+     L_NUM = 282,
+     L_EQ = 283,
+     L_IS = 284,
+     L_LIKE = 285,
+     L_GT = 286,
+     L_LT = 287,
+     L_GEQ = 288,
+     L_LEQ = 289,
+     L_DIFF = 290,
+     L_REGEXP = 291,
+     L_REGEXP_CI = 292,
+     L_NOTREGEXP = 293,
+     L_NOTREGEXP_CI = 294,
+     L_SIMILAR = 295,
+     L_NOT = 296,
+     L_AND = 297,
+     L_OR = 298,
+     L_MINUS = 299,
+     L_PLUS = 300,
+     L_TIMES = 301,
+     L_DIV = 302,
+     L_STRING = 303,
+     L_TEXTUAL = 304,
+     L_DELETE = 305,
+     L_JOIN = 306,
+     L_INNER = 307,
+     L_LEFT = 308,
+     L_RIGHT = 309,
+     L_FULL = 310,
+     L_OUTER = 311,
+     L_LSBRACKET = 312,
+     L_RSBRACKET = 313,
+     L_PNAME = 314,
+     L_PTYPE = 315,
+     L_PISPARAM = 316,
+     L_PDESCR = 317,
+     L_PNULLOK = 318,
+     L_UNSPECVAL = 319,
+     L_SIMPLE_PARAM = 320
    };
 #endif
 /* Tokens.  */
@@ -127,50 +129,52 @@
 #define L_LBRACKET 279
 #define L_RBRACKET 280
 #define L_IDENT 281
-#define L_EQ 282
-#define L_IS 283
-#define L_LIKE 284
-#define L_GT 285
-#define L_LT 286
-#define L_GEQ 287
-#define L_LEQ 288
-#define L_DIFF 289
-#define L_REGEXP 290
-#define L_REGEXP_CI 291
-#define L_NOTREGEXP 292
-#define L_NOTREGEXP_CI 293
-#define L_SIMILAR 294
-#define L_NOT 295
-#define L_AND 296
-#define L_OR 297
-#define L_MINUS 298
-#define L_PLUS 299
-#define L_TIMES 300
-#define L_DIV 301
-#define L_STRING 302
-#define L_TEXTUAL 303
-#define L_DELETE 304
-#define L_JOIN 305
-#define L_INNER 306
-#define L_LEFT 307
-#define L_RIGHT 308
-#define L_FULL 309
-#define L_OUTER 310
-#define L_LSBRACKET 311
-#define L_RSBRACKET 312
-#define L_PNAME 313
-#define L_PTYPE 314
-#define L_PISPARAM 315
-#define L_PDESCR 316
-#define L_PNULLOK 317
-#define L_UNSPECVAL 318
+#define L_NUM 282
+#define L_EQ 283
+#define L_IS 284
+#define L_LIKE 285
+#define L_GT 286
+#define L_LT 287
+#define L_GEQ 288
+#define L_LEQ 289
+#define L_DIFF 290
+#define L_REGEXP 291
+#define L_REGEXP_CI 292
+#define L_NOTREGEXP 293
+#define L_NOTREGEXP_CI 294
+#define L_SIMILAR 295
+#define L_NOT 296
+#define L_AND 297
+#define L_OR 298
+#define L_MINUS 299
+#define L_PLUS 300
+#define L_TIMES 301
+#define L_DIV 302
+#define L_STRING 303
+#define L_TEXTUAL 304
+#define L_DELETE 305
+#define L_JOIN 306
+#define L_INNER 307
+#define L_LEFT 308
+#define L_RIGHT 309
+#define L_FULL 310
+#define L_OUTER 311
+#define L_LSBRACKET 312
+#define L_RSBRACKET 313
+#define L_PNAME 314
+#define L_PTYPE 315
+#define L_PISPARAM 316
+#define L_PDESCR 317
+#define L_PNULLOK 318
+#define L_UNSPECVAL 319
+#define L_SIMPLE_PARAM 320
 
 
 
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 17 "parser.y"
+#line 71 "../libsql/parser.y"
 {
 void            *v;
 char            *str;
@@ -184,8 +188,8 @@ sql_where       *w;
 param_spec      *ps;
 sql_order_field *of;
 }
-/* Line 1529 of yacc.c.  */
-#line 189 "parser.h"
+/* Line 1489 of yacc.c.  */
+#line 193 "parser.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
